==> openshift-model-6.3.1-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaSelectorFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ClusterResourceQuotaSelectorFluent<A extends ClusterResourceQuotaSelectorFluent<A>> extends Fluent<A>{
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  
  /**
   * This method has been deprecated, please use method buildLabels instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getLabels();
  public LabelSelector buildLabels();
  public A withLabels(LabelSelector labels);
  public Boolean hasLabels();
  public ClusterResourceQuotaSelectorFluent.LabelsNested<A> withNewLabels();
  public ClusterResourceQuotaSelectorFluent.LabelsNested<A> withNewLabelsLike(LabelSelector item);
  public ClusterResourceQuotaSelectorFluent.LabelsNested<A> editLabels();
  public ClusterResourceQuotaSelectorFluent.LabelsNested<A> editOrNewLabels();
  public ClusterResourceQuotaSelectorFluent.LabelsNested<A> editOrNewLabelsLike(LabelSelector item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LabelsNested<N> extends Nested<N>,LabelSelectorFluent<ClusterResourceQuotaSelectorFluent.LabelsNested<N>>{
    public N and();
    public N endLabels();
    
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaSelectorFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterResourceQuotaSelectorFluent<A extends ClusterResourceQuotaSelectorFluent<A>> extends Fluent<A>{
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  
  /**
   * This method has been deprecated, please use method buildLabels instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getLabels();
  public LabelSelector buildLabels();
  public A withLabels(LabelSelector labels);
  public Boolean hasLabels();
  public ClusterResourceQuotaSelectorFluent.LabelsNested<A> withNewLabels();
  public ClusterResourceQuotaSelectorFluent.LabelsNested<A> withNewLabelsLike(LabelSelector item);
  public ClusterResourceQuotaSelectorFluent.LabelsNested<A> editLabels();
  public ClusterResourceQuotaSelectorFluent.LabelsNested<A> editOrNewLabels();
  public ClusterResourceQuotaSelectorFluent.LabelsNested<A> editOrNewLabelsLike(LabelSelector item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LabelsNested<N> extends Nested<N>,LabelSelectorFluent<ClusterResourceQuotaSelectorFluent.LabelsNested<N>>{
    public N and();
    public N endLabels();
    
  }
  
}
